C+
C NAME:
C	Time1TwoThousand
C PURPOSE:
C	Convert from 1-element standard time to time relative to
C	2000 Jan 1, 0 UT and v.v.
C CATEGORY:
C	gen/for/lib
C CALLING SEQUENCE:
	subroutine Time1TwoThousand(id,t,u)
C INPUTS:
C	id		integer		0  converts to time relative to 2000 Jan 1, 0 UT
C					1  converts from time relative to 2000 Jan 1, 0 UT
C	t		integer		id=0: time relative to current origin
C					id=1: time relative to 2000 Jan 1, 0 UT
C OUTPUTS:
C	u		integer		id=0: time relative to 2000 Jan 1, 0 UT
C					id=1: time relative to current origin
C CALLS:
C	Time2GetOrigin2000, Time1StandardOrigin
C PROCEDURE:
C MODIFICATION HISTORY:
C	OCT-2003, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C-
	    integer	id
	    integer	t
	    integer	u

	integer		t0(3)

	call Time2GetOrigin2000(t0)
	call Time1StandardOrigin(t0,id,t,u)

	return
C+
C NAME:
C	Time1JD
C PURPOSE:
C	Convert from 1-element standard time to Julian day and v.v
C CATEGORY:
C	gen/for/lib
C CALLING SEQUENCE:
	entry Time1JD(id,t,u)
C INPUTS:
C	id		integer		0  converts time to Julian day
C					1  converts Julian day to time
C	t		integer		id=0: time relative to current origin
C					id=1: time in Julian day
C OUTPUTS:
C	u		integer		id=0: time in Julian day
C					id=1: time relative to current origin
C CALLS:
C	Time2GetOriginJD, Time1StandardOrigin
C PROCEDURE:
C MODIFICATION HISTORY:
C	OCT-2003, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C-
	call Time2GetOriginJD(t0)
	call Time1StandardOrigin(t0,id,t,u)

	return
C+
C NAME:
C	Time1MJD
C PURPOSE:
C	Convert from 1-element standard time to modified Julian day and v.v.
C CATEGORY:
C	gen/for/lib
C CALLING SEQUENCE:
	entry Time1MJD(id,t,u)
C INPUTS:
C	id		integer		0  converts time to modified Julian day
C					1  converts modified Julian day to time
C	n		integer		# times
C	t		integer		id=0: time relative to current origin
C					id=1: time in modified Julian days
C OUTPUTS:
C	u		integer		id=0: time in modified Julian day
C					id=1: time relative to current origin
C CALLS:
C	Time2GetOriginMJD, Time1StandardOrigin
C PROCEDURE:
C MODIFICATION HISTORY:
C	OCT-2003, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C-
	call Time2GetOriginMJD(t0)
	call Time1StandardOrigin(t0,id,t,u)

	return
	end
